@@ -816,3 +816,43 @@ dend2 <- assign_values_to_leaves_edgePar(dend=dend, value = col_aa_red, edgePar
 plot(dend2)
 
 
+## ------------------------------------------------------------------------
+## mtcars example
+
+# Create the dend:
+dend <- as.dendrogram(hclust(dist(mtcars)))
+
+# Create a vector giving a color for each car to which company it belongs to
+car_type <- rep("Other", length(rownames(mtcars)))
+is_x <- grepl("Merc", rownames(mtcars))
+car_type[is_x] <- "Mercedes"
+is_x <- grepl("Mazda", rownames(mtcars))
+car_type[is_x] <- "Mazda"
+is_x <- grepl("Toyota", rownames(mtcars))
+car_type[is_x] <- "Toyota"
+car_type <- factor(car_type)
+n_car_types <- length(unique(car_type))
+cols_4 <- colorspace::rainbow_hcl(n_car_types, c = 70, l  = 50)
+col_car_type <- cols_4[car_type]
+
+# extra: showing the various clusters cuts 
+k234 <- cutree(dend, k = 2:4)
+
+# color labels by car company:
+labels_colors(dend) <- col_car_type[order.dendrogram(dend)]
+# color branches based on cutting the tree into 4 clusters:
+dend <- color_branches(dend, k = 4)
+
+### plots
+par(mar = c(12,4,1,1))
+plot(dend)
+colored_bars(cbind(k234[,3:1], col_car_type), dend, rowLabels = c(paste0("k = ", 4:2), "Car Type"))
+
+# horiz version:
+# dend <- sort(dend)
+par(mar = c(4,1,1,12))
+plot(dend, horiz = TRUE)
+colored_bars(cbind(k234[,3:1], col_car_type), dend, rowLabels = c(paste0("k = ", 4:2), "Car Type"), horiz = TRUE)
+legend("topleft", legend = levels(car_type), fill = cols_4)
+
+
