@@ -1,14 +1,21 @@
 library(testthat)
 
 library(dendextend)
-test_package("dendextend")
+tryCatch(test_package("dendextend"), 
+         error = function(e) 
+            cat('Please run: testthat::test_dir("tests\\testthat")')
+         )
 
 #
 
 library(dendextendRcpp)
-test_package("dendextend")
+tryCatch(test_package("dendextend"), 
+         error = function(e) 
+            cat('Please run: testthat::test_dir("tests\\testthat")')
+)
 
-# testthat::test_dir("inst\\tests")
+
+# testthat::test_dir("tests\\testthat")
 
 # library(dendextend)
 # system.time(test_dir("inst\\tests")) # 12.8  (- 21)
